# @summary
#    Ensure bootloader password is set 
#
# Setting the boot loader password will require that anyone rebooting the system must enter a password 
# before being able to set command line boot parameters
#
# Notes:
# * This recommendation is designed around the grub2 bootloader, if LILO or another bootloader is in use in 
#    your environment enact equivalent settings. Replace `/boot/grub2/grub.cfg with the appropriate grub 
#    configuration file for your environment
# * For older grub2 based systems:
#   o The superuser/user information and password should not be contained in the
#     /etc/grub.d/00_header file. The information can be placed in any /etc/grub.d file as long as that file 
#     is incorporated into grub.cfg. The user may prefer to enter this data into a custom file, such as 
#     /etc/grub.d/40_custom so it is not overwritten should the Grub package be updated.
#   o If placing the information in a custom file, do not include the "cat << EOF" and "EOF" lines as the content 
#     is automatically added from these files.
#
# Rationale:
# Requiring a boot password upon execution of the boot loader will prevent an unauthorized user from entering boot 
# parameters or changing the boot partition. This prevents users from weakening security (e.g. turning off SELinux 
# at boot time).
#
# @param enforce
#    Enforce the rule
#
# @param grub_password_pbkdf2
#    Encrypted grub password.
#
# @example
#   class { 'cis_security_hardening::rules::grub_password':
#       enforce              => true,
#       grub_password_pbkdf2 => 'grub.pbkdf2.sha512.10000.943.......',
#   }
# 
# @api private
class cis_security_hardening::rules::grub_password (
  Boolean $enforce                       = false,
  Optional[String] $grub_password_pbkdf2 = undef,
) {
  if $enforce {
    if !$grub_password_pbkdf2 {
      fail('Enforcing a grub boot password needs a grub password to be defined. Please define an encrypted grub password in Hiera.')
    } else {
      $grub_path = fact('cis_security_hardening.efi') ? {
        true    => "/boot/efi/EFI/${facts['os']['name'].downcase()}",
        default => '/boot/grub2',
      }

      case $facts['os']['family'].downcase() {
        'redhat': {
          file { "${grub_path}/user.cfg":
            ensure  => file,
            content => "GRUB2_PASSWORD=${grub_password_pbkdf2}",
            owner   => 'root',
            group   => 'root',
            mode    => fact('cis_security_hardening.efi') ? { true => '0700', default => '0600' },
            notify  => Exec['bootpw-grub-config'],
          }

          exec { 'bootpw-grub-config':
            command     => "grub2-mkconfig -o ${grub_path}/grub.cfg",
            path        => ['/bin', '/usr/bin', '/sbin', '/usr/sbin'],
            refreshonly => true,
          }
        }
        'debian': {
          file_line { 'grub-unrestricted':
            ensure             => present,
            path               => '/etc/grub.d/10_linux',
            line               => 'CLASS="--class gnu-linux --class gnu --class os --unrestricted"',
            match              => '^CLASS="--class gnu-linux --class gnu --class os"',
            append_on_no_match => false,
            notify             => Exec['bootpw-grub-config-ubuntu'],
          }

          file { '/etc/grub.d/50_custom':
            ensure  => file,
            content => epp('cis_security_hardening/rules/common/ubuntu_grub_user.cfg.epp', {
                password => $grub_password_pbkdf2,
            }),
            owner   => 'root',
            group   => 'root',
            mode    => '0755',
            notify  => Exec['bootpw-grub-config-ubuntu'],
          }

          exec { 'bootpw-grub-config-ubuntu':
            command     => fact('cis_security_hardening.efi') ? {
              true    => "update-grub -o ${grub_path}/grub.cfg",
              default => 'update-grub'
            },
            path        => ['/bin', '/usr/bin', '/sbin', '/usr/sbin'],
            refreshonly => true,
          }
        }
        'suse': {
          file { '/etc/grub.d/40_custom':
            ensure  => file,
            content => epp('cis_security_hardening/rules/common/ubuntu_grub_user.cfg.epp', {
                password => $grub_password_pbkdf2,
            }),
            owner   => 'root',
            group   => 'root',
            mode    => '0755',
            notify  => Exec['bootpw-grub-config-sles'],
          }

          exec { 'bootpw-grub-config-sles':
            command     => "grub2-mkconfig -o ${grub_path}/grub.cfg",
            path        => ['/bin', '/usr/bin', '/sbin', '/usr/sbin'],
            refreshonly => true,
          }
        }
        default: {
          # nothing to do yet
        }
      }
    }
  }
}
