# @summary 
#    Ensure system timezone is set to UTC or GMT
#
# The Ubuntu operating system must record time stamps for audit records that can be mapped to 
# Coordinated Universal Time (UTC) or Greenwich Mean Time (GMT).
#
# Rationale:
# If time stamps are not consistently applied and there is no common time reference, it is difficult 
# to perform forensic analysis.
#
# Time stamps generated by the operating system include date and time. Time is commonly expressed in 
# Coordinated Universal Time (UTC), a modern continuation of Greenwich Mean Time (GMT), or local 
# time with an offset from UTC.
#
# @param enforce
#    Enforce the rule.
# @param timezone
#    Timezone to set, allowed are UTC or GMT.
#
# @example
#   class  'cis_security_hardening::rules::timezone_utc_gmt':
#     enforce => true,
#     timezone => 'UTC'
#   }
#
# @api private
class cis_security_hardening::rules::timezone_utc_gmt (
  Boolean $enforce              = false,
  Enum['UTC', 'GMT'] $timezone  = 'UTC',
) {
  if $enforce {
    exec { 'set timezone':
      command => "timedatectl set-timezone ${timezone}", #lint:ignore:security_class_or_define_parameter_in_exec
      path    => ['/bin', '/usr/bin'],
      onlyif  => "test -z \"$(timedatectl status | grep -i 'time zone' | grep ${timezone})\"",
    }
  }
}
